ApiModelController class abstract

Implementers

Constructors

ApiModelController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

auth(String apiKey) Future<Map>
createDocument(String? idToken, Map data, DocumentTypes type) Future<Map>
deleteDocument(String? idToken, String reference, DocumentTypes type) Future<Map>
downloadDocumentBytes(String? idToken, String url, DocumentTypes type) Future<Uint8List?>
findDocument(String? idToken, String number, DocumentTypes type) Future<Map>
findRutDian(String? idToken, String identificationNumber, String identificationTypeId) Future<Map>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readData(String? idToken, String listName) Future<Map>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited