FacturasoftController class

Implemented types

Constructors

FacturasoftController()

Properties

apiController ApiController
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

auth(String apiKey) Future<Map>
override
createDocument(String? idToken, Map data, DocumentTypes type) Future<Map>
override
deleteDocument(String? idToken, String reference, DocumentTypes type) Future<Map>
override
downloadDocumentBytes(String? idToken, String reference, DocumentTypes type) Future<Uint8List?>
override
findDocument(String? idToken, String id, DocumentTypes type) Future<Map>
override
findRutDian(String? idToken, String identificationNumber, String identificationTypeId) Future<Map>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readData(String? idToken, String listName, {String? date}) Future<Map>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited