AuthServiceInterface class abstract

Constructors

AuthServiceInterface()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createUser(String email, String password) → Future<Map?>
getCurrentProfile() → Future<Map?>
getCurrentProfileFromApi(String endpoint) → Future<Map?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendPasswordReset(String email) → Future<void>
signInWithEmail(String email, String password) → Future<Map?>
signInWithGoogle() → Future<Map?>
signOut() → Future<void>
toString() → String
A string representation of this object.
inherited
updateUser(String displayName, String phoneNumber) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited