CustomAppBarModal class

Inheritance

Constructors

CustomAppBarModal({Key? key, TextStyle? titleStyle, String title = '', Widget? titleWidget, String? subtitle, bool centerTitle = false, bool iconSwipe = false, List leftButtons = const [], List rightButtons = const [], Color? backgroundColor, Color? textColor, Map options = const {}, bool showOnlyOption = false, ButtonType buttonType = ButtonType.text})

Properties

backgroundColor → Color?
finalinherited
bottom → TabBar?
finalinherited
buttonType → ButtonType
final
centerTitle → bool
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
iconSwipe → bool
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
language → Language
final
leftButtons → List
finalinherited
options → Map
final
preferredSize → Size
The size this widget would prefer if it were otherwise unconstrained.
no setterinherited
rightButtons → List
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showOnlyOption → bool
final
subtitle → String?
finalinherited
subtitleStyle → TextStyle?
finalinherited
textColor → Color?
finalinherited
title → String
finalinherited
titleStyle → TextStyle?
finalinherited
titleWidget → Widget?
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createButton(dynamic context, String action, ButtonType type, Function onPressed) → Widget
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited