CustomColors class

Implementers

Constructors

CustomColors()

Properties

email → Color
final
error → Color
final
hashCode → int
The hash code for this object.
no setterinherited
mapNavigate → Color
final
messages → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → Color
final
surface → Color
final
warning → Color
final
whatsapp → Color
final

Methods

customColorsNames({ColorScheme? colorScheme}) → Map<String, Color?>
getColorByName(String colorName, {ColorScheme? colorScheme}) → Color?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited