CustomCounterButton class

Inheritance

Constructors

CustomCounterButton({Key? key, int currentValue = 0, Function? onChanged, Color? iconLeftColor, Color? iconRightColor, bool openCalc = true, double? height = 48, double? width = 128, int? flex, EdgeInsets? margin, EdgeInsets? padding = const EdgeInsets.symmetric(horizontal: 8), BorderRadius? borderRadius = const BorderRadius.all(Radius.circular(8)), Color? backgroundColor})
const

Properties

backgroundColor → Color?
finalinherited
border → BorderSide?
finalinherited
borderRadius → BorderRadius?
finalinherited
buttonStyle → ButtonStyle?
finalinherited
child → Widget?
finalinherited
currentValue → int
final
disabled → bool
finalinherited
elevation → double?
finalinherited
flex → int?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
finalinherited
iconLeftColor → Color?
final
iconRightColor → Color?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftIcon → Widget?
finalinherited
margin → EdgeInsets?
finalinherited
onChanged → Function?
final
onPressed → Function?
finalinherited
openCalc → bool
final
overlayColor → Color?
finalinherited
padding → EdgeInsets?
finalinherited
rightIcon → Widget?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
finalinherited
textAlign → TextAlign?
finalinherited
textColor → Color?
finalinherited
textStyle → TextStyle?
finalinherited
visualDensity → VisualDensity?
finalinherited
width → double?
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited