CustomListTile class

Inheritance
Implementers

Constructors

CustomListTile({Key? key, GestureTapCallback? onTap, GestureLongPressCallback? onLongPress, Color? textColor, Widget? leading, Widget? trailing, Widget? title, Widget? subtitle, VisualDensity? visualDensity, bool? dense = false, double? horizontalTitleGap = 12, double? minVerticalPadding = 4, double? minLeadingWidth = 24, EdgeInsetsGeometry? contentPadding = const EdgeInsets.symmetric(horizontal: 16), Color? tileColor, Color? splashColor, Color? selectedTileColor, bool selected = false, bool disabled = false, Widget? trailingBottom, Widget? footerLeft, Widget? footerRight, double? opacity, BoxBorder? border, BorderRadius? borderRadius, EdgeInsets? margin = const EdgeInsets.all(0), CrossAxisAlignment? crossAxisAlignment, MainAxisAlignment? mainAxisAlignment, MainAxisSize mainAxisSize = MainAxisSize.min, TextStyle? titleStyle, TextStyle? subtitleStyle, int maxLinesTitle = 1, int maxLinesSubtitle = 1, String? textTitle, String? textSubtitle, bool invertTitlePosition = false})
const

Properties

autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
border → BoxBorder?
final
borderRadius → BorderRadius?
final
contentPadding → EdgeInsetsGeometry?
The tile's internal padding.
finalinherited
crossAxisAlignment → CrossAxisAlignment?
final
dense → bool?
Whether this list tile is part of a vertically dense list.
finalinherited
disabled → bool
final
enabled → bool
Whether this list tile is interactive.
finalinherited
enableFeedback → bool?
Whether detected gestures should provide acoustic and/or haptic feedback.
finalinherited
focusColor → Color?
The color for the tile's Material when it has the input focus.
finalinherited
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
footerLeft → Widget?
final
footerRight → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalTitleGap → double?
The horizontal gap between the titles and the leading/trailing widgets.
finalinherited
hoverColor → Color?
The color for the tile's Material when a pointer is hovering over it.
finalinherited
iconColor → Color?
Defines the default color for leading and trailing icons.
finalinherited
internalAddSemanticForOnTap → bool
Whether to add button:true to the semantics if onTap is provided. This is a temporary flag to help changing the behavior of ListTile onTap semantics.
finalinherited
invertTitlePosition → bool
final
isThreeLine → bool?
Whether this list tile is intended to display three lines of text.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
A widget to display before the title.
finalinherited
leadingAndTrailingTextStyle → TextStyle?
The text style for ListTile's leading and trailing.
finalinherited
mainAxisAlignment → MainAxisAlignment?
final
mainAxisSize → MainAxisSize
final
margin → EdgeInsets?
final
maxLinesSubtitle → int
final
maxLinesTitle → int
final
minLeadingWidth → double?
The minimum width allocated for the ListTile.leading widget.
finalinherited
minTileHeight → double?
The minimum height allocated for the ListTile widget.
finalinherited
minVerticalPadding → double?
The minimum padding on the top and bottom of the title and subtitle widgets.
finalinherited
mouseCursor → MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
finalinherited
onFocusChange → ValueChanged<bool>?
Handler called when the focus changes.
finalinherited
onLongPress → GestureLongPressCallback?
Called when the user long-presses on this list tile.
finalinherited
onTap → GestureLongPressCallback?
Called when the user taps this list tile.
finalinherited
opacity → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
If this tile is also enabled then icons and text are rendered with the same color.
finalinherited
selectedColor → Color?
Defines the color used for icons and text when the list tile is selected.
finalinherited
selectedTileColor → Color?
Defines the background color of ListTile when selected is true.
finalinherited
shape → ShapeBorder?
Defines the tile's InkWell.customBorder and Ink.decoration shape.
finalinherited
splashColor → Color?
The color of splash for the tile's Material.
finalinherited
statesController → MaterialStatesController?
Represents the interactive "state" of this widget in terms of a set of WidgetStates, like WidgetState.pressed and WidgetState.focused.
finalinherited
style → ListTileStyle?
Defines the font used for the title.
finalinherited
subtitle → Widget?
Additional content displayed below the title.
finalinherited
subtitleStyle → TextStyle?
final
subtitleTextStyle → TextStyle?
The text style for ListTile's subtitle.
finalinherited
textColor → Color?
Defines the text color for the title, subtitle, leading, and trailing.
finalinherited
textSubtitle → String?
final
textTitle → String?
final
tileColor → Color?
Defines the background color of ListTile when selected is false.
finalinherited
title → Widget?
The primary content of the list tile.
finalinherited
titleAlignment → ListTileTitleAlignment?
Defines how ListTile.leading and ListTile.trailing are vertically aligned relative to the ListTile's titles (ListTile.title and ListTile.subtitle).
finalinherited
titleStyle → TextStyle?
final
titleTextStyle → TextStyle?
The text style for ListTile's title.
finalinherited
trailing → Widget?
A widget to display after the title.
finalinherited
trailingBottom → Widget?
final
visualDensity → VisualDensity?
Defines how compact the list tile's layout will be.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getLeftLabels(dynamic context) → List<Widget>
getRightLabels() → List<Widget>
getSubtitleWidget(dynamic context) → Widget?
getTitleWidget(dynamic context) → Widget?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited