CustomMenuButton class

Inheritance

Constructors

CustomMenuButton({Key? key, required Function onChanged, required dynamic items, String? selectedKey, String? firstOption, String? keyItemName, String hint = 'Select', Function? onPressed, String? text, Color? backgroundColor, Color? textColor, Color? overlayColor, Widget? child, Widget? leftIcon, Widget? rightIcon, bool disabled = false, TextStyle? textStyle, EdgeInsets? margin, EdgeInsets? padding, double? height, double? width, double? elevation, int? flex, BorderRadius? borderRadius, BorderSide? border, TextAlign? textAlign, VisualDensity? visualDensity, ButtonStyle? buttonStyle})
const

Properties

backgroundColor → Color?
finalinherited
border → BorderSide?
finalinherited
borderRadius → BorderRadius?
finalinherited
buttonStyle → ButtonStyle?
finalinherited
child → Widget?
finalinherited
disabled → bool
finalinherited
elevation → double?
finalinherited
firstOption → String?
final
flex → int?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
finalinherited
hint → String
final
items → dynamic
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyItemName → String?
final
leftIcon → Widget?
finalinherited
margin → EdgeInsets?
finalinherited
onChanged → Function
final
onPressed → Function?
finalinherited
overlayColor → Color?
finalinherited
padding → EdgeInsets?
finalinherited
rightIcon → Widget?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedKey → String?
final
text → String?
finalinherited
textAlign → TextAlign?
finalinherited
textColor → Color?
finalinherited
textStyle → TextStyle?
finalinherited
visualDensity → VisualDensity?
finalinherited
width → double?
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited