CustomMessage class

Inheritance

Constructors

CustomMessage({Key? key, String title = '', String? subtitle, String? message, Icon? icon, TextAlign? textAlign = TextAlign.center, Color? backgroundColor, Color? textColor, BoxBorder? border, BorderRadius? borderRadius, EdgeInsets? padding = const EdgeInsets.all(16), EdgeInsets? margin = const EdgeInsets.all(16), TextStyle? titleStyle, TextStyle? subtitleStyle, TextStyle? messageStyle, bool isCard = false, double? elevation = 8, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, Axis direction = Axis.vertical})
const

Properties

backgroundColor → Color?
final
border → BoxBorder?
final
borderRadius → BorderRadius?
final
crossAxisAlignment → CrossAxisAlignment
final
direction → Axis
final
elevation → double?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Icon?
final
isCard → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsets?
final
message → String?
final
messageStyle → TextStyle?
final
padding → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → String?
final
subtitleStyle → TextStyle?
final
textAlign → TextAlign?
final
textColor → Color?
final
title → String
final
titleStyle → TextStyle?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited