CustomMessageAlert class

Inheritance

Constructors

CustomMessageAlert({Key? key, MessageType? type, bool showIcon = false, String title = '', String? subtitle, String? message, TextAlign? textAlign = TextAlign.start, Axis direction = Axis.horizontal, EdgeInsets? margin = const EdgeInsets.all(16), EdgeInsets? padding = const EdgeInsets.all(16), BoxBorder? border, BorderRadius? borderRadius, TextStyle? titleStyle, TextStyle? subtitleStyle, TextStyle? messageStyle})
const

Properties

backgroundColor → Color?
finalinherited
border → BoxBorder?
finalinherited
borderRadius → BorderRadius?
finalinherited
crossAxisAlignment → CrossAxisAlignment
finalinherited
direction → Axis
finalinherited
elevation → double?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → Icon?
finalinherited
isCard → bool
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsets?
finalinherited
message → String?
finalinherited
messageStyle → TextStyle?
finalinherited
padding → EdgeInsets?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showIcon → bool
final
subtitle → String?
finalinherited
subtitleStyle → TextStyle?
finalinherited
textAlign → TextAlign?
finalinherited
textColor → Color?
finalinherited
title → String
finalinherited
titleStyle → TextStyle?
finalinherited
type → MessageType?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited