CustomText class

Inheritance

Constructors

CustomText(String data, {Key? key, TextStyle? style, StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, double? textScaleFactor, TextScaler? textScaler, int? maxLines, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Color? selectionColor, int? flex, Color? color, double? fontSize, double? letterSpacing = 0.5, FontWeight? fontWeight, TextDecoration? decoration = TextDecoration.none, Color? backgroundColor})
const

Properties

backgroundColor → Color?
final
color → Color?
final
data → String?
The text to display.
finalinherited
decoration → TextDecoration?
final
flex → int?
final
fontSize → double?
final
fontWeight → FontWeight?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letterSpacing → double?
final
locale → Locale?
Used to select a font when the same Unicode character can be rendered differently, depending on the locale.
finalinherited
maxLines → int?
An optional maximum number of lines for the text to span, wrapping if necessary. If the text exceeds the given number of lines, it will be truncated according to overflow.
finalinherited
overflow → TextOverflow?
How visual overflow should be handled.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionColor → Color?
The color to use when painting the selection.
finalinherited
semanticsIdentifier → String?
A unique identifier for the semantics node for this widget.
finalinherited
semanticsLabel → String?
An alternative semantics label for this text.
finalinherited
softWrap → bool?
Whether the text should break at soft line breaks.
finalinherited
strutStyle → StrutStyle?
The strut style to use. Strut style defines the strut, which sets minimum vertical layout metrics.
finalinherited
style → TextStyle?
If non-null, the style to use for this text.
finalinherited
textAlign → TextAlign?
How the text should be aligned horizontally.
finalinherited
textDirection → TextDirection?
The directionality of the text.
finalinherited
textHeightBehavior → TextHeightBehavior?
Defines how to apply TextStyle.height over and under text.
finalinherited
textScaleFactor → double?
Deprecated. Will be removed in a future version of Flutter. Use textScaler instead.
finalinherited
textScaler → TextScaler?
The font scaling strategy to use when laying out and rendering the text.
finalinherited
textSpan → InlineSpan?
The text to display as a InlineSpan.
finalinherited
textWidthBasis → TextWidthBasis?
Defines how to measure the width of the rendered text.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited