CustomTextField class

Inheritance

Constructors

CustomTextField({Key? key, double? height, double? width, EdgeInsets? margin, EdgeInsets? padding, bool disabled = false, bool obscureText = false, bool autocorrect = false, bool dense = false, bool filled = false, bool alignLabelWithHint = true, bool singleLine = false, bool noSpace = false, Color? backgroundColor, Color? borderColor, BorderRadius? borderRadius, BorderSide? enabledBorderSide, BorderSide? focusedBorderSide, BorderSide? disabledBorderSide, int? flex, int? minLines = 1, int? maxLines = 1, int? maxLength, String? initialValue, String? hintText, String? labelText, TextStyle? style, TextStyle? hintStyle, TextStyle? labelStyle, TextStyle? floatingLabelStyle, TextAlign textAlign = TextAlign.start, Widget? prefix, Widget? prefixIcon, Widget? suffix, Widget? suffixIcon, Widget? counter, TextEditingController? controller, TextInputType? keyboardType, TextCapitalization textCapitalization = TextCapitalization.sentences, InputFormat? inputFormat, List<TextInputFormatter> inputFormatters = const [], FocusNode? focusNode, Function? onEditingComplete, Function? onChanged, Function? validator})
const

Properties

alignLabelWithHint → bool
final
autocorrect → bool
final
backgroundColor → Color?
final
borderColor → Color?
final
borderRadius → BorderRadius?
final
controller → TextEditingController?
final
counter → Widget?
final
dense → bool
final
disabled → bool
final
disabledBorderSide → BorderSide?
final
enabledBorderSide → BorderSide?
final
filled → bool
final
flex → int?
final
floatingLabelStyle → TextStyle?
final
focusedBorderSide → BorderSide?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
hintStyle → TextStyle?
final
hintText → String?
final
initialValue → String?
final
inputFormat → InputFormat?
final
inputFormatters → List<TextInputFormatter>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
labelStyle → TextStyle?
final
labelText → String?
final
margin → EdgeInsets?
final
maxLength → int?
final
maxLines → int?
final
minLines → int?
final
noSpace → bool
final
obscureText → bool
final
onChanged → Function?
final
onEditingComplete → Function?
final
padding → EdgeInsets?
final
prefix → Widget?
final
prefixIcon → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleLine → bool
final
style → TextStyle?
final
suffix → Widget?
final
suffixIcon → Widget?
final
textAlign → TextAlign
final
textCapitalization → TextCapitalization
final
validator → Function?
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited