MenuDialog class

Constructors

Properties

callback → Function
final
context → BuildContext
final
firstOption → String?
final
formattedItems ↔ List<Map<String, String>>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items → dynamic
final
keyItemName → String?
final
maxShowItems → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedKey → String?
final

Methods

getSelectedItem() → Map<String, String>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited