ServiceStatus enum

Defines the different states a service can be in.

Inheritance
Available extensions

Values

disabled → const ServiceStatus

The service for the permission is disabled.

enabled → const ServiceStatus

The service for the permission is enabled.

notApplicable → const ServiceStatus

The permission does not have an associated service on the current platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isDisabled → bool

Available on ServiceStatus, provided by the ServiceStatusGetters extension

If the service for the permission is disabled.
no setter
isEnabled → bool

Available on ServiceStatus, provided by the ServiceStatusGetters extension

If the service for the permission is enabled.
no setter
isNotApplicable → bool

Available on ServiceStatus, provided by the ServiceStatusGetters extension

If the permission does not have an associated service on the current platform.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ServiceStatus>
A constant List of the values in this enum, in order of their declaration.