WaitingTimeOutException class

Implemented types

Constructors

WaitingTimeOutException(Map<String, List<String>> areWaitedBy, List<String> notReadyYet, List<String> areReady)

Properties

areReady → List<String>
Lists with Types that are already ready.
final
areWaitedBy → Map<String, List<String>>
In case of a timeout while waiting for an instance to get ready This exception is thrown with information about who is still waiting.
final
hashCode → int
The hash code for this object.
no setterinherited
notReadyYet → List<String>
Lists with Types that are still not ready.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited