FileService class

Constructors

FileService()

Properties

fileServiceAndroid FileServiceAndroid
getter/setter pair
fileServiceWeb FileServiceWeb
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
optionsExcel OptionsExcel
final
optionsImage OptionsImage
final
optionsInvoice OptionsInvoice
final
optionsPDF OptionsPDF
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveBytes(Uint8List bytes, String fileName, String fileExtension) Future<Map>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited