FileServiceAndroid class

Constructors

FileServiceAndroid()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readFile(dynamic context, String fileExtension) → Future<Uint8List?>
saveBytes(Uint8List bytes, String fileName, String fileExtension) → Future<Map>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited