OptionsExcel class

Constructors

OptionsExcel()

Properties

fileServiceAndroid FileServiceAndroid
final
fileServiceWeb FileServiceWeb
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildExcel(List<String> keys, List<List> values, {String? sheetName}) Future<Uint8List?>
convertExcelToMap(dynamic context) Future<Map<String, List<Map<String, dynamic>>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveExcel(List<String> keys, List<List> values, String fileName, {String? sheetName}) Future<Map>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited