OptionsImage class

Constructors

OptionsImage()

Properties

fileServiceAndroid FileServiceAndroid
final
fileServiceWeb FileServiceWeb
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildImage(GlobalKey<State<StatefulWidget>> globalKey, double quality) Future<Uint8List?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveImage(GlobalKey<State<StatefulWidget>> globalKey, double quality, String fileName) Future<Map>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited