OptionsPDF class

Constructors

OptionsPDF()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBytes(Uint8List bytes) Future<void>
shareBytes(Uint8List bytes, String fileName) Future<void>
showBytes(Uint8List bytes, PdfPageFormat pageFormat) Future<Widget>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited