Account class

Constructors

Account({String? id, String? name, String? role, String? state, String? logoBase64})
Account.fromObject(Map data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
final
logoBase64 String?
final
name String?
final
role String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
final

Methods

getLogoBase64() String
getLogoUint8List() Uint8List?
getName() String
getRole() String
getState() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited