Customer class

Inheritance

Constructors

Customer({String? name, String? identificationTypeId, String? identificationNumber, String? dv, String? responsabilityTypeId, String? regimeTypeId, String? organizationTypeId, String? municipalityId, String? address, String? phone, String? email, String? state, String? commercialRegistration})
Customer.fromEntry(MapEntry entry)
factory
Customer.fromObject(Map data)
factory

Properties

address String?
finalinherited
commercialRegistration String?
final
dv String?
finalinherited
email String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
identificationNumber String?
finalinherited
identificationTypeId String?
finalinherited
labelTicket String
no setteroverride
legalRepresentative String?
finalinherited
merchantRegistry String?
finalinherited
municipalityId String?
finalinherited
name String?
finalinherited
organizationTypeId String?
finalinherited
phone String?
finalinherited
regimeTypeId String?
finalinherited
responsabilityTypeId String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
finalinherited

Methods

getAddress() String
inherited
getDv() String?
inherited
getEmail() String
inherited
getId() String
inherited
getIdentificationLabel() String
inherited
getIdentificationNumber() String
inherited
getIdentificationType() IdentificationType
inherited
getIdentificationTypeId() String
inherited
getInfoGeo() String
inherited
getInfoResponsability() String
inherited
getLegalRepresentative() String
inherited
getMerchantRegistry() String
inherited
getMunicipality() Municipality
inherited
getMunicipalityId() String
inherited
getName() String
inherited
getNitComplete() String
inherited
getOrganizationType() OrganizationType
inherited
getOrganizationTypeId() String
inherited
getPhone() String
inherited
getRegimeType() RegimeType
inherited
getRegimeTypeId() String
inherited
getResponsabilityType() ResponsabilityType
inherited
getResponsabilityTypeId() String
inherited
getState() String
inherited
isEmpty() bool
inherited
isNotEmpty() bool
inherited
isValid() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
inherited
toOrder() Map<String, dynamic>
toSave() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited