DocumentType class

Constructors

DocumentType({String? id, String? code, String? name, String? prefix, String? algorithm})
DocumentType.fromEntry(MapEntry entry)
factory
DocumentType.fromId(String id)
factory

Properties

algorithm → String?
final
code → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
name → String?
final
prefix → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAlgorithm() → String
getCode() → String
getId() → String
getName() → String
getPrefix() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromObject(Map object, {String? id}) → DocumentType