IdentificationType class

Constructors

IdentificationType({String? id, String? code, String? name, bool? added})
IdentificationType.fromEntry(MapEntry entry)
factory
IdentificationType.fromId(String id)
factory
IdentificationType.fromObject(Map object, {String? id})
factory

Properties

added → bool?
final
code → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAdded() → bool
getCode() → String
getId() → String
getName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAdd() → Map
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited