Municipality class

Constructors

Municipality({String? id, String? code, String? name, String? departmentId})
Municipality.fromEntry(MapEntry entry)
factory
Municipality.fromId(String id)
factory
Municipality.fromObject(Map data)
factory

Properties

code String?
final
departmentId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCode() String
getDeparment() Department
getDepartmentId() String
getId() String
getName() String
isEmpty() bool
isNotEmpty() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited