Profile class
Constructors
Properties
- disabled → bool?
-
final
- displayName → String?
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- incomplete → bool
-
final
- phoneNumber → String?
-
final
- photoURL → String?
-
final
- roles → Map
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uid → String?
-
final
Methods
-
getDisabled(
) → bool -
getDisplayName(
) → String -
getEmail(
) → String -
getIncomplete(
) → bool -
getPhoneNumber(
) → String -
getPhotoURL(
) → String -
getRoles(
) → Map -
getUid(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setRoles(
Map newRoles) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited