DefaultObject class

Constructors

DefaultObject({String? id, String? code, String? name, bool? added})
DefaultObject.fromEntry(MapEntry entry)
factory
DefaultObject.fromObject(Map data)
factory

Properties

added ↔ bool?
getter/setter pair
code → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAdded() → bool
getCode() → String
getId() → String
getName() → String
isEmpty() → bool
isNotEmpty() → bool
isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAdded(bool isAdded) → void
toAdd() → Map
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited