App class

Constructors

App({String? id, String? key, String? name, String? description, String? state})
App.fromEntry(MapEntry entry)
factory
App.fromObject(Map object, {String? id})
factory

Properties

description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
key → String?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
final

Methods

getDescription() → String
getId() → String
getKey() → String
getName() → String
getState() → String
isEmpty() → bool
isNotEmpty() → bool
isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited