Charge class

Constructors

Charge({String? id, bool? isCharge, String? reason, double? percent, double? amount, double? base})
Charge.fromEntry(MapEntry entry)
factory
Charge.fromObject(Map object, {String? id})
factory

Properties

amount double?
final
base double?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
isCharge bool?
final
percent double?
final
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAmount() double
getBase() double
getId() String
getIsCharge() bool
getPercent() double
getReason() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited