Client class

Constructors

Client({String? id, String? key, String? keyApi, String? accountId, String? applicationId, bool? disabled, String? name, String? nit, String? dv, String? responsabilityTypeId, String? regimeTypeId, String? organizationTypeId, String? municipalityId, String? address, String? phone, String? email, String? state, String? legalRepresentative, bool isTest = false})
Client.fromEntry(MapEntry map)
factory
Client.fromObject(Map data, {String? id})
factory

Properties

accountId → String?
final
address → String?
final
applicationId → String?
final
dianUrl → String
no setter
disabled → bool?
final
dv → String?
final
email → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isTest → bool
final
key → String?
final
keyApi → String?
final
label → String
no setter
labelTicket → String
no setter
legalRepresentative → String?
final
final
municipalityId → String?
final
name → String?
final
nit → String?
final
organizationTypeId → String?
final
phone → String?
final
regimeTypeId → String?
final
responsabilityTypeId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
final

Methods

getAddress() → String
getApplicationId() → String
getDepartment() → Department
getDv() → String
getEmail() → String
getId() → String
getIdentificationType() → IdentificationType
getKey() → String
getKeyApi() → String
getLegalRepresentative() → String
getMunicipality() → Municipality
getMunicipalityId() → String
getName() → String
getNit() → String
getNitComplete() → String
getOrganizationType() → OrganizationType
getOrganizationTypeId() → String
getPhone() → String
getRegimeType() → RegimeType
getRegimeTypeId() → String
getResponsabilityType() → ResponsabilityType
getResponsabilityTypeId() → String
getState() → String
isEmpty() → bool
isNotEmpty() → bool
isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toSave() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited