Person class
Constructors
- Person({String? name, String? identificationTypeId, String? identificationNumber, String? dv, String? responsabilityTypeId, String? regimeTypeId, String? organizationTypeId, String? municipalityId, String? address, String? phone, String? email, String? state, String? legalRepresentative, String? merchantRegistry})
- Person.fromEntry(MapEntry entry)
-
factory
- Person.fromObject(Map data)
-
factory
Properties
- address → String?
-
final
- dv → String?
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identificationNumber → String?
-
final
- identificationTypeId → String?
-
final
- labelTicket → String
-
no setter
- legalRepresentative → String?
-
final
- merchantRegistry → String?
-
final
- municipalityId → String?
-
final
- name → String?
-
final
- organizationTypeId → String?
-
final
- phone → String?
-
final
- regimeTypeId → String?
-
final
- responsabilityTypeId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
final
Methods
-
getAddress(
) → String -
getDv(
) → String? -
getEmail(
) → String -
getId(
) → String -
getIdentificationLabel(
) → String -
getIdentificationNumber(
) → String -
getIdentificationType(
) → IdentificationType -
getIdentificationTypeId(
) → String -
getInfoGeo(
) → String -
getInfoResponsability(
) → String -
getLegalRepresentative(
) → String -
getMerchantRegistry(
) → String -
getMunicipality(
) → Municipality -
getMunicipalityId(
) → String -
getName(
) → String -
getNitComplete(
) → String -
getOrganizationType(
) → OrganizationType -
getOrganizationTypeId(
) → String -
getPhone(
) → String -
getRegimeType(
) → RegimeType -
getRegimeTypeId(
) → String -
getResponsabilityType(
) → ResponsabilityType -
getResponsabilityTypeId(
) → String -
getState(
) → String -
isEmpty(
) → bool -
isNotEmpty(
) → bool -
isValid(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toSave(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited