User class

Constructors

User({String? uid, String? displayName, String? phoneNumber, String? email, String? photoURL, String? role, String? state, bool? disabled})
User.fromEntry(MapEntry map)
factory
User.fromObject(Map data)
factory

Properties

disabled → bool?
final
displayName → String?
final
email → String?
final
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → String?
final
photoURL → String?
final
role → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
final
uid → String?
final

Methods

getDisabled() → bool
getDisplayName() → String
getEmail() → String
getPhoneNumber() → String
getPhotoURL() → String
getRole() → String
getState() → String
getUid() → String
isEmpty() → bool
isNotEmpty() → bool
isOwner() → bool
isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toRole() → Map<String, dynamic>
toSave() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited