ApiProvider class

Constructors

ApiProvider()

Properties

client ValueNotifier<Client?>
final
controller FacturasoftController
final
controllerNext NextPymeController
final
currents ValueNotifier<Map>
final
dateMovements ValueNotifier<DateTime?>
final
hashCode int
The hash code for this object.
no setterinherited
idToken ValueNotifier<String>
final
invoices ValueNotifier<Map>
final
movements ValueNotifier<Map>
final
refreshToken ValueNotifier<String>
final
resolutions ValueNotifier<Map>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildInvoiceMapFromXml(XmlDocument xml) Map<String, dynamic>
create(Map data, DocumentTypes type) Future<Map>
decodeXmlFromBase64(String base64Str) String
delete(String reference, DocumentTypes type) Future<Map>
dispose() → dynamic
downloadDocument(String number, DocumentTypes type) Future<Uint8List?>
downloadFile(Uint8List bytes, String fileName, String fileExtension) Future<Map>
find(String number, DocumentTypes type) Future<Map>
findRut(String identificationNumber, String identificationTypeId) Future<Map>
getDateString() String
init(String? apiKey) → dynamic
loadDataFromApi() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseXml(String xmlStr) → XmlDocument
read(String listName) Future<Map>
refreshInvoices() Future<void>
restart(String? apiKey) → dynamic
saveDocument(Uint8List? responseBytes, String number, DocumentTypes type) Future<Map>
showInDianPage(String? cufe) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited