ApiController class

Constructors

ApiController(String apiUrl)

Properties

apiUrl String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

auth(String endpoint, String apiKey) Future<Map>
delete(String? idToken, String endpoint) Future<Map>
downloadBytes(String? idToken, String endpoint) Future<Uint8List?>
get(String? idToken, String endpoint) Future<Map>
getImageBytesFromUrl(String? url) Future<Uint8List?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String? idToken, String endpoint, dynamic data) Future<Map>
put(String? idToken, String endpoint, dynamic data) Future<Map>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited