libraries
library
Classes
AppBarButtonIcon
AppBarButtonText
AuthScreen
AuthServiceInterface
Bidi
This provides utility methods for working with bidirectional text. All
of the methods are static, and are organized into a class primarily to
group them together for documentation and discoverability.
BidiFormatter
Bidi stands for Bi-directional text. According to
Wikipedia :
Bi-directional text is text containing text in both text directionalities,
both right-to-left (RTL) and left-to-right (LTR). It generally involves text
containing different types of alphabets, but may also refer to
boustrophedon, which is changing text directionality in each row.
BrowserConfiguration
Additional configuration options for LaunchMode.inAppBrowserView
ButtonDrawer
CompleteProfileScreen
ContentConfirmDelete
CustomAppBar
CustomAppBarModal
CustomAppBarSignout
CustomCard
CustomCardExpandible
CustomColors
CustomCounterButton
CustomDivider
CustomDropdownButton
CustomElevatedButton
CustomGridTile
CustomIcons
CustomIndicator
CustomListTile
CustomLoading
CustomMessage
CustomMessageAlert
CustomTableCell
CustomTableColumn
CustomTableRow
CustomText
CustomTextCode
CustomTextField
CustomTextSearch
CustomTileButton
CustomToggleButton
DateFormat
DateFormat is for formatting and parsing dates in a locale-sensitive
manner.
Disposable
If objects that are registered inside GetIt implements Disposable the
onDispose method will be called whenever that Object is unregistered,
resetted or its enclosing Scope is popped
GetIt
Very simple and easy to use service locator
You register your object creation factory or an instance of an object with registerFactory ,
registerSingleton or registerLazySingleton
And retrieve the desired object using get or call your locator as function as its a
callable class
Additionally GetIt offers asynchronous creation functions as well as functions to synchronize
the async initialization of multiple Singletons
IconSwipe
InitDependency
Data structure used to identify a dependency by type and instanceName
Intl
The Intl class provides a common entry point for internationalization
related tasks. An Intl instance can be created for a particular locale
and used to create a date format via anIntl.date(). Static methods
on this class are also used in message formatting.
Ionicons
Use with the Icon class to show specific icons.
IoniconsData
A description of an icon fulfilled by a font glyph.
Language
MdiIcons
MessagesScreen
MicroMoney
Used primarily for currency formatting, this number-like class stores
millionths of a currency unit, typically as an Int64.
ModalContentActionsBottom
NumberFormat
Provides the ability to format a number in a locale-specific way.
NumberParserBase <R >
OptionsDirection
OptionsEmail
OptionsPhone
Permission
Defines the permissions which can be checked and requested.
PermissionWithService
A special kind of permission, used to access a service.
ShadowChangeHandlers
If an object implements the ShadowChangeHandler if will get notified if
an Object with the same registration type and name is registered on a
higher scope which will shadow it.
It also will get notified if the shadowing object is removed from GetIt
SharedPreferences
Wraps NSUserDefaults (on iOS) and SharedPreferences (on Android), providing
a persistent store for simple data.
SharedPreferencesAsync
Provides a persistent store for simple data.
SharedPreferencesOptions
Basic options for creating SharedPreferencesAsync classes.
SharedPreferencesWithCache
Provides a persistent store for simple data.
SharedPreferencesWithCacheOptions
Options necessary to create a SharedPreferencesWithCache .
Sizes
Spaces
TextDirection
Represents directionality of text.
Uuid
uuid for Dart
Author: Yulian Kuncheff
Released under MIT License.
UuidValue
WebViewConfiguration
Additional configuration options for LaunchMode.inAppWebView .
WillSignalReady
If your singleton that you register wants to use the manually signalling
of its ready state, it can implement this interface class instead of using
the signalsReady parameter of the registration functions
(you don't really have to implement much ;-) )
Functions
canLaunch (String urlString )
→ Future <bool >
Checks whether the specified URL can be handled by some app installed on the
device.
canLaunchUrl (Uri url )
→ Future <bool >
Checks whether the specified URL can be handled by some app installed on the
device.
canLaunchUrlString (String urlString )
→ Future <bool >
String version of canLaunchUrl .
CAPITALIZE_FIRST (String text )
→ String
CAPITALIZE_WORDS (String text )
→ String
closeInAppWebView ()
→ Future <void >
Closes the current in-app web view, if one was previously opened by
launchUrl .
closeWebView ()
→ Future <void >
Closes the current WebView, if one was previously opened via a call to launch .
COMBINE_DATE_HOURAUTO (DateTime date )
→ DateTime
COUNT_CHILDS (dynamic context , dynamic values )
→ int
CREATE_DATE (DateTime date )
→ String
CREATE_DAY_NAME (DateTime date )
→ String
CREATE_HOUR (DateTime date )
→ String
CREATE_HOUR_AUTOMATICALLY ()
→ String
CREATE_ID_WITH_DATE (DateTime date )
→ String
CREATE_ID_WITH_DATE_AUTOMATICALLY ()
→ String
CREATE_ID_WITH_DATETIME (DateTime date )
→ String
CREATE_ID_WITH_DATETIME_AUTOMATICALLY ()
→ String
CREATE_ID_WITH_MONTH (DateTime date )
→ String
CREATE_ID_WITH_PREFIX (String prefix )
→ String
CREATE_ID_WITH_TIME (DateTime date )
→ String
CREATE_MONTH_NAME (DateTime date )
→ String
CREATE_TIME (DateTime date )
→ String
customAutoDialog (dynamic context , Widget child )
→ Future <void >
customShowDialog (dynamic context , Widget child )
→ Future <void >
customShowModalBottomSheet (dynamic context , Widget child )
→ Future <void >
FORMAT_CURRENCY_DOUBLE (dynamic number , {int ? decimals })
→ String
FORMAT_CURRENCY_INT (int number )
→ String
GET_IMAGE_FILE (File imageFile , dynamic customHeight , dynamic customWidth , dynamic iconDefault , dynamic customRadius , {Color ? iconColor })
→ Widget
GET_IMAGE_NETWORK (dynamic imageUrl , dynamic customHeight , dynamic customWidth , dynamic iconDefault , dynamic customRadius , {Color ? iconColor })
→ Widget
GET_STRING_CUTED (String label , int maxCharts )
→ String
getOptionWidget (dynamic context , OptionsItem ? option , Map ? person )
→ Widget ?
IS_FULL_WIDTH (dynamic context )
→ bool
IS_PORTRAIT (dynamic context )
→ bool
IS_WEB (dynamic context )
→ bool
isPortrait (dynamic context )
→ bool
launch (String urlString , {bool ? forceSafariVC , bool forceWebView = false , bool enableJavaScript = false , bool enableDomStorage = false , bool universalLinksOnly = false , Brightness ? statusBarBrightness , String ? webOnlyWindowName })
→ Future <bool >
Parses the specified URL string and delegates handling of it to the
underlying platform.
launchUrl (Uri url , {LaunchMode mode = LaunchMode.platformDefault , WebViewConfiguration webViewConfiguration = const WebViewConfiguration() , BrowserConfiguration browserConfiguration = const BrowserConfiguration() , String ? webOnlyWindowName })
→ Future <bool >
Passes url to the underlying platform for handling.
launchUrlString (String urlString , {LaunchMode mode = LaunchMode.platformDefault , WebViewConfiguration webViewConfiguration = const WebViewConfiguration() , BrowserConfiguration browserConfiguration = const BrowserConfiguration() , String ? webOnlyWindowName })
→ Future <bool >
String version of launchUrl .
ModalCalc (dynamic context , String label , String currentValue , Function callback , bool currency )
→ void
openAppSettings ()
→ Future <bool >
Opens the app settings page.
REMOVE_HOUR_FROM_DATE (DateTime date )
→ DateTime
showSnackBar (BuildContext context , SnackType ? type , String ? message )
→ void
SUM_VALUES_FROM_MAP (Map <String , dynamic > data )
→ double
supportsCloseForLaunchMode (LaunchMode mode )
→ Future <bool >
Returns true if closeInAppWebView is supported for mode in the current
platform implementation.
supportsLaunchMode (LaunchMode mode )
→ Future <bool >
Returns true if mode is supported by the current platform implementation.
throwIf (bool condition , Object error )
→ void
Two handy functions that help me to express my intention clearer and shorter to check for runtime
errors
throwIfNot (bool condition , Object error )
→ void
TO_DOUBLE (dynamic value , {int ? decimals })
→ double
TO_DOUBLE_NULABLE (dynamic value , {int ? decimals })
→ double ?
TO_STRING (dynamic value )
→ String
TO_STRING_NULLABLE (dynamic value )
→ String ?
toBeginningOfSentenceCase <T extends String ? > (T input , [String ? locale ])
→ T
Convert a string to beginning of sentence case, in a way appropriate to the
locale.
Typedefs
DisposingFunc <T >
= FutureOr Function(T param )
Signature for disposing function
because closures like (x){} have a return type of Null we don't use FutureOr<void>
FactoryFunc <T >
= T Function()
Signature of the factory function used by non async factories
FactoryFuncAsync <T >
= Future <T > Function()
Signature of the factory function used by async factories
FactoryFuncParam <T , P1 , P2 >
= T Function(P1 param1 , P2 param2 )
For Factories that expect up to two parameters if you need only one use void for the one
you don't use
FactoryFuncParamAsync <T , P1 , P2 >
= Future <T > Function(P1 param1 , P2 param2 )
For async Factories that expect up to two parameters if you need only one use void for the one
you don't use
ScopeDisposeFunc
= FutureOr Function()
Signature for disposing function on scope level