DocumentOptions class

Constructors

DocumentOptions({required BuildContext context, required Invoice invoice, required PdfColor surfaceColor, required PdfColor primaryColor, PdfColor backgroundColor = PdfColors.white, PdfColor textColor = PdfColors.blueGrey800})

Properties

backgroundColor → PdfColor
final
context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
invoice Invoice
final
primaryColor → PdfColor
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surfaceColor → PdfColor
final
textColor → PdfColor
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited