Establishment class
Constructors
- Establishment({String? nit, String? name, String? address, String? phone, String? municipalityId, String? email, String? logo, String? economicActivity, String? legalRepresentative, String? dv, String? organizationTypeId, String? regimeTypeId, String? responsabilityTypeId, bool isTest = false})
- Establishment.fromEntry(MapEntry entry)
-
factory
- Establishment.fromObject(Map map)
-
factory
Properties
- address → String?
-
final
- dianUrl → String
-
no setter
- dv → String?
-
final
- economicActivity → String?
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTest → bool
-
final
- label → String
-
no setter
- labelTicket → String
-
no setter
- legalRepresentative → String?
-
final
- logo → String?
-
final
- municipalityId → String?
-
final
- name → String?
-
final
- nit → String?
-
final
- organizationTypeId → String?
-
final
- phone → String?
-
final
- regimeTypeId → String?
-
final
- responsabilityTypeId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAddress(
) → String -
getDepartment(
) → Department -
getDv(
) → String -
getEconomicActivity(
) → String -
getEmail(
) → String -
getLegalRepresentative(
) → String -
getLogo(
) → String -
getLogoUint8List(
) → Uint8List? -
getMunicipality(
) → Municipality -
getMunicipalityId(
) → String -
getName(
) → String -
getNit(
) → String -
getNitComplete(
) → String -
getOrganizationType(
) → OrganizationType -
getOrganizationTypeId(
) → String -
getPhone(
) → String -
getRegimeType(
) → RegimeType -
getRegimeTypeId(
) → String -
getResponsabilityType(
) → ResponsabilityType -
getResponsabilityTypeId(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited