Resolution class

Constructors

Resolution({String? id, String? documentTypeId, String? prefix, int? from, int? to, int? consecutive, String? number, String? dateFrom, String? dateTo, String? technicalKey, bool? isExpired, int? isActive, String? createdAt, String? updatedAt})
Resolution.fromApi(Map data)
factory
Resolution.fromEntry(MapEntry entry)
factory
Resolution.fromObject(Map data, {String? id})
factory

Properties

consecutive int?
final
createdAt String?
final
dateFrom String?
final
dateTo String?
final
documentTypeId String?
final
from int?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
isActive int?
final
isExpired bool?
final
number String?
final
prefix String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
technicalKey String?
final
to int?
final
updatedAt String?
final

Methods

getConsecutive() int
getCreatedAt() String
getDateFrom() String
getDateTo() String
getDocumentName() String
getDocumentTypeId() String
getFrom() int
getId() String
getIsExpired() bool
getNumber() String
getPrefix() String
getRange() String
getTechnicalKey() String
getTo() int
getUpdatedAt() String
getValidity() String
isEmpty() bool
isNotEmpty() bool
isValid() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited