Service class

Inheritance

Constructors

Service({String? code, bool? disabled, String? photoURL, String? name, String? description, String? notes, int? quantity, double? price, String? measureId, String? reference})
Service.fromEntry(MapEntry map)
factory
Service.fromObject(Map data)
factory

Properties

charges Map?
finalinherited
code String?
finalinherited
cost double?
finalinherited
description String?
finalinherited
disabled bool?
final
discountRate double?
no setterinherited
discountTotal double
getter/setter pairinherited
discountUnity double
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
incrementRate double?
no setterinherited
incrementTotal double
getter/setter pairinherited
incrementUnity double
getter/setter pairinherited
isExcluded bool
getter/setter pairinherited
itsFree bool?
finalinherited
measureId String?
finalinherited
name String?
finalinherited
notes String?
finalinherited
photoURL String?
final
price double?
finalinherited
priceUnity double
getter/setter pairinherited
priceUpdated double
getter/setter pairinherited
priceUpdatedSubtotal double
getter/setter pairinherited
priceUpdatedTotal double
getter/setter pairinherited
priceUpdatedUnity double
getter/setter pairinherited
quantity int?
getter/setter pairinherited
quantityBase double?
finalinherited
reference String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
standardCodeId String?
finalinherited
stock double?
finalinherited
subtotal double
getter/setter pairinherited
supplierId String?
finalinherited
supplierName String?
finalinherited
taxes List<Tax>?
finalinherited
taxTotal double
getter/setter pairinherited
taxUnity double
getter/setter pairinherited
taxUpdatedUnity double
getter/setter pairinherited
total double?
finalinherited

Methods

cleaned() Map<String, dynamic>
inherited
getCharges() Map
inherited
getCode() String
inherited
getCost() double
inherited
getCurrencyPrice() String
inherited
getCurrencyPriceSubtotal() String
inherited
getCurrencyPriceUnity() String
inherited
getCurrencyPriceUpdated() String
inherited
getCurrencyPriceUpdatedSubtotal() String
inherited
getCurrencyPriceUpdatedTotal() String
inherited
getCurrencyPriceUpdatedUnity() String
inherited
getCurrencyTaxTotal() String
inherited
getCurrencyTaxUnity() String
inherited
getCurrencyTaxUpdatedTotal() String
inherited
getCurrencyTaxUpdatedUnity() String
inherited
getCurrencyTotal() String
inherited
getDescription() String
inherited
getDescriptionWeb() String
inherited
getDisabled() bool
getDiscountRate() double
inherited
getDiscountRateDecimal() double
inherited
getDiscountTotal() double
inherited
getDiscountUnity() double
inherited
getIncrementRate() double
inherited
getIncrementRateDecimal() double
inherited
getIncrementTotal() double
inherited
getIncrementUnity() double
inherited
getMeasure() Measure
inherited
getMeasureId() String
inherited
getName() String
inherited
getNames() String
inherited
getNote() String
inherited
getPrice() double
inherited
getPriceUnity() double
inherited
getPriceUpdated() double
inherited
getPriceUpdatedSubtotal() double
inherited
getPriceUpdatedTotal() double
inherited
getPriceUpdatedUnity() double
inherited
getQuantity() int
inherited
getQuantityLabel() String
inherited
getReference() String
inherited
getReferenceNew() String
inherited
getStock() double
inherited
getSubtotal() double
inherited
getSupplierId() String
inherited
getSupplierName() String
inherited
getTaxes() List<Tax>
inherited
getTaxesList() List
inherited
getTaxTotal() double
inherited
getTaxUnity() double
inherited
getTaxUpdatedTotal() double
inherited
getTaxUpdatedUnity() double
inherited
getTotal() double
inherited
isEmpty() bool
inherited
isNotEmpty() bool
inherited
isValid() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setQuantity(int quantity2) → void
inherited
toApi() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
override
toSave() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited