Role class

Constructors

Role({String? uid, String? role, String? state})
Role.fromObject(Map data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
role String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
final
uid String?
final

Methods

isEmpty() bool
isNotEmpty() bool
isValid() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFirestore() Map
toMap() Map
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited