DefaultProvider class
Constructors
Properties
-
all
→ ValueNotifier<
Map> -
final
-
apiKeys
→ ValueNotifier<
Map> -
final
-
departments
→ ValueNotifier<
Map> -
final
-
discounts
→ ValueNotifier<
Map< String, dynamic> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
identificationTypes
→ ValueNotifier<
Map< String, dynamic> > -
final
-
measures
→ ValueNotifier<
Map> -
final
-
municipalities
→ ValueNotifier<
Map> -
final
-
organizationTypes
→ ValueNotifier<
Map< String, dynamic> > -
final
-
paymentForms
→ ValueNotifier<
Map< String, dynamic> > -
final
-
paymentMethods
→ ValueNotifier<
Map> -
final
-
productCodeTypes
→ ValueNotifier<
Map< String, dynamic> > -
final
-
regimeTypes
→ ValueNotifier<
Map< String, dynamic> > -
final
-
responsabilityTypes
→ ValueNotifier<
Map< String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
support
→ ValueNotifier<
Map> -
final
-
taxTypes
→ ValueNotifier<
Map< String, dynamic> > -
final
Methods
-
dispose(
) → dynamic -
init(
Map data) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restart(
Map data) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited