AppColors class
- Inheritance
-
- Object
- CustomColors
- AppColors
Constructors
Properties
- email → Color
-
finalinherited
- error → Color
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
finalinherited
- messages → Color
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → Color
-
finalinherited
- surface → Color
-
finalinherited
- warning → Color
-
finalinherited
- whatsapp → Color
-
finalinherited
Methods
-
colorsNamesFacts(
{ColorScheme? colorScheme, bool? isDark}) → Map< String, Color?> -
customColorsNames(
{ColorScheme? colorScheme}) → Map< String, Color?> -
inherited
-
getColorByName(
String colorName, {ColorScheme? colorScheme, bool? isDark}) → Color? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited